// Copyright (c) 2020 The Bitcoin Core developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.

#include <consensus/amount.h>
#include <feerate.h>
#include <policy/fees.h>

#include <test/fuzz/FuzzedDataProvider.h>
#include <test/fuzz/fuzz.h>
#include <test/fuzz/util.h>

#include <cstdint>
#include <string>
#include <vector>

FUZZ_TARGET(fees) {
    FuzzedDataProvider fuzzed_data_provider(buffer.data(), buffer.size());
    const CFeeRate minimal_incremental_fee{ConsumeMoney(fuzzed_data_provider)};
    FastRandomContext rng{/*fDeterministic=*/true};
    FeeFilterRounder fee_filter_rounder{minimal_incremental_fee, rng};
    while (fuzzed_data_provider.ConsumeBool()) {
        const Amount current_minimum_fee = ConsumeMoney(fuzzed_data_provider);
        const Amount rounded_fee =
            fee_filter_rounder.round(current_minimum_fee);
        assert(MoneyRange(rounded_fee));
    }
}
